@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import List, Optional
 
 from easydata.exceptions import DropItem
 
@@ -23,24 +23,8 @@ ED_DATETIME_LOCALES: Optional[List[str]] = None
 ED_DATETIME_REGION: Optional[str] = None
 
 # Config attributes used by url parsers
-ED_URL_DOMAIN: Optional[str] = None
-
 ED_URL_PROTOCOL: str = "https"
 
-# Config attributes used by number parsers
-ED_NUMBER_DECIMALS: Union[int, bool] = False
-
-ED_NUMBER_MIN_VALUE: Optional[Union[int, float]] = None
-
-ED_NUMBER_MAX_VALUE: Optional[Union[int, float]] = None
-
-# Config attributes used by price parsers
-ED_PRICE_DECIMALS: Union[int, bool] = 2
-
-ED_PRICE_MIN_VALUE: Optional[Union[int, float]] = None
-
-ED_PRICE_MAX_VALUE: Optional[Union[int, float]] = None
-
 # Config attributes used by DataXmlToDictProcessor
 ED_DATA_XML_TO_DICT_ITEM_DEPTH: int = 0
 
