@@ -1,4 +1,3 @@
-from easydata.parsers.base import *  # noqa: F401 F403
 from easydata.parsers.bool import *  # noqa: F401 F403
 from easydata.parsers.choice import *  # noqa: F401 F403
 from easydata.parsers.clause import *  # noqa: F401 F403
@@ -8,9 +7,10 @@ from easydata.parsers.dict import *  # noqa: F401 F403
 from easydata.parsers.drop import *  # noqa: F401 F403
 from easydata.parsers.email import *  # noqa: F401 F403
 from easydata.parsers.list import *  # noqa: F401 F403
+from easydata.parsers.math import *  # noqa: F401 F403
 from easydata.parsers.misc import *  # noqa: F401 F403
 from easydata.parsers.number import *  # noqa: F401 F403
-from easydata.parsers.price import *  # noqa: F401 F403
+from easydata.parsers.price import PriceFloat, PriceInt, PriceText  # noqa: F401 F403
 from easydata.parsers.text import *  # noqa: F401 F403
 from easydata.parsers.time import *  # noqa: F401 F403
 from easydata.parsers.url import *  # noqa: F401 F403
