@@ -1,9 +1,12 @@
+from easydata.queries.clause import OrClause, WithClause
 from easydata.queries.jp import JMESPathSearch, JMESPathStrictSearch
 from easydata.queries.key import KeySearch, KeyStrictSearch
 from easydata.queries.pq import PyQuerySearch, PyQueryStrictSearch
-from easydata.queries.qs import Queries
 from easydata.queries.re import ReSearch, ReStrictSearch
 
+cwith = WithClause
+cor = OrClause
+
 jp = JMESPathSearch
 jp_strict = JMESPathStrictSearch
 
@@ -13,7 +16,5 @@ key_strict = KeyStrictSearch
 pq = PyQuerySearch
 pq_strict = PyQueryStrictSearch
 
-qs = Queries
-
 re = ReSearch
 re_strict = ReStrictSearch
