@@ -2,11 +2,16 @@ from typing import Any, Optional
 
 import jmespath
 
-from easydata.queries.key import KeyQuery
+from easydata.queries.key import KeySearch
+
+__all__ = (
+    "JMESPathSearch",
+    "JMESPathStrictSearch",
+)
 
 
-class JMESPathSearch(KeyQuery):
-    def _parse(
+class JMESPathSearch(KeySearch):
+    def parse(
         self,
         data: Any,
         query: Optional[str],
@@ -19,3 +24,7 @@ class JMESPathSearch(KeyQuery):
             )
 
         return self._process_data_key_values(data)
+
+
+class JMESPathStrictSearch(JMESPathSearch):
+    strict = True
